@@ -18,7 +18,7 @@
 # [This file includes modifications made by New Vector Limited]
 #
 #
-from typing import Optional, Sequence
+from typing import Sequence
 from unittest.mock import AsyncMock, Mock
 
 from typing_extensions import TypeAlias
@@ -190,9 +190,7 @@ class ApplicationServiceSchedulerRecovererTestCase(unittest.HomeserverTestCase):
         # return one txn to send, then no more old txns
         txns = [txn, None]
 
-        def take_txn(
-            *args: object, **kwargs: object
-        ) -> "defer.Deferred[Optional[Mock]]":
+        def take_txn(*args: object, **kwargs: object) -> "defer.Deferred[Mock | None]":
             return defer.succeed(txns.pop(0))
 
         self.store.get_oldest_unsent_txn = Mock(side_effect=take_txn)
@@ -216,9 +214,7 @@ class ApplicationServiceSchedulerRecovererTestCase(unittest.HomeserverTestCase):
         txns = [txn, None]
         pop_txn = False
 
-        def take_txn(
-            *args: object, **kwargs: object
-        ) -> "defer.Deferred[Optional[Mock]]":
+        def take_txn(*args: object, **kwargs: object) -> "defer.Deferred[Mock | None]":
             if pop_txn:
                 return defer.succeed(txns.pop(0))
             else:
@@ -254,9 +250,7 @@ class ApplicationServiceSchedulerRecovererTestCase(unittest.HomeserverTestCase):
         txns = [txn, None]
         pop_txn = False
 
-        def take_txn(
-            *args: object, **kwargs: object
-        ) -> "defer.Deferred[Optional[Mock]]":
+        def take_txn(*args: object, **kwargs: object) -> "defer.Deferred[Mock | None]":
             if pop_txn:
                 return defer.succeed(txns.pop(0))
             else:
@@ -291,11 +285,11 @@ defer.Deferred[
     tuple[
         ApplicationService,
         Sequence[EventBase],
-        Optional[list[JsonDict]],
-        Optional[list[JsonDict]],
-        Optional[TransactionOneTimeKeysCount],
-        Optional[TransactionUnusedFallbackKeys],
-        Optional[DeviceListUpdates],
+        list[JsonDict] | None,
+        list[JsonDict] | None,
+        TransactionOneTimeKeysCount | None,
+        TransactionUnusedFallbackKeys | None,
+        DeviceListUpdates | None,
     ]
 ]
 """
