@@ -17,7 +17,7 @@
 # [This file includes modifications made by New Vector Limited]
 #
 #
-from typing import Callable, Optional
+from typing import Callable
 from unittest.mock import AsyncMock, Mock
 
 from signedjson import key, sign
@@ -510,7 +510,7 @@ class FederationSenderDevicesTestCases(HomeserverTestCase):
         )
 
     async def record_transaction(
-        self, txn: Transaction, json_cb: Optional[Callable[[], JsonDict]] = None
+        self, txn: Transaction, json_cb: Callable[[], JsonDict] | None = None
     ) -> JsonDict:
         assert json_cb is not None
         data = json_cb()
@@ -592,7 +592,7 @@ class FederationSenderDevicesTestCases(HomeserverTestCase):
 
         # expect two edus
         self.assertEqual(len(self.edus), 2)
-        stream_id: Optional[int] = None
+        stream_id: int | None = None
         stream_id = self.check_device_update_edu(self.edus.pop(0), u1, "D1", stream_id)
         stream_id = self.check_device_update_edu(self.edus.pop(0), u1, "D2", stream_id)
 
@@ -754,7 +754,7 @@ class FederationSenderDevicesTestCases(HomeserverTestCase):
 
         # for each device, there should be a single update
         self.assertEqual(len(self.edus), 3)
-        stream_id: Optional[int] = None
+        stream_id: int | None = None
         for edu in self.edus:
             self.assertEqual(edu["edu_type"], EduTypes.DEVICE_LIST_UPDATE)
             c = edu["content"]
@@ -876,7 +876,7 @@ class FederationSenderDevicesTestCases(HomeserverTestCase):
         edu: JsonDict,
         user_id: str,
         device_id: str,
-        prev_stream_id: Optional[int],
+        prev_stream_id: int | None,
     ) -> int:
         """Check that the given EDU is an update for the given device
         Returns the stream_id.
