@@ -19,7 +19,7 @@
 #
 #
 
-from typing import Any, Collection, Optional
+from typing import Any, Collection
 from unittest.mock import AsyncMock, Mock
 
 from twisted.internet.testing import MemoryReactor
@@ -63,10 +63,10 @@ class TestSpamChecker:
 
     async def check_registration_for_spam(
         self,
-        email_threepid: Optional[dict],
-        username: Optional[str],
+        email_threepid: dict | None,
+        username: str | None,
         request_info: Collection[tuple[str, str]],
-        auth_provider_id: Optional[str],
+        auth_provider_id: str | None,
     ) -> RegistrationBehaviour:
         return RegistrationBehaviour.ALLOW
 
@@ -74,10 +74,10 @@ class TestSpamChecker:
 class DenyAll(TestSpamChecker):
     async def check_registration_for_spam(
         self,
-        email_threepid: Optional[dict],
-        username: Optional[str],
+        email_threepid: dict | None,
+        username: str | None,
         request_info: Collection[tuple[str, str]],
-        auth_provider_id: Optional[str],
+        auth_provider_id: str | None,
     ) -> RegistrationBehaviour:
         return RegistrationBehaviour.DENY
 
@@ -85,10 +85,10 @@ class DenyAll(TestSpamChecker):
 class BanAll(TestSpamChecker):
     async def check_registration_for_spam(
         self,
-        email_threepid: Optional[dict],
-        username: Optional[str],
+        email_threepid: dict | None,
+        username: str | None,
         request_info: Collection[tuple[str, str]],
-        auth_provider_id: Optional[str],
+        auth_provider_id: str | None,
     ) -> RegistrationBehaviour:
         return RegistrationBehaviour.SHADOW_BAN
 
@@ -96,10 +96,10 @@ class BanAll(TestSpamChecker):
 class BanBadIdPUser(TestSpamChecker):
     async def check_registration_for_spam(
         self,
-        email_threepid: Optional[dict],
-        username: Optional[str],
+        email_threepid: dict | None,
+        username: str | None,
         request_info: Collection[tuple[str, str]],
-        auth_provider_id: Optional[str] = None,
+        auth_provider_id: str | None = None,
     ) -> RegistrationBehaviour:
         # Reject any user coming from CAS and whose username contains profanity
         if auth_provider_id == "cas" and username and "flimflob" in username:
@@ -113,8 +113,8 @@ class TestLegacyRegistrationSpamChecker:
 
     async def check_registration_for_spam(
         self,
-        email_threepid: Optional[dict],
-        username: Optional[str],
+        email_threepid: dict | None,
+        username: str | None,
         request_info: Collection[tuple[str, str]],
     ) -> RegistrationBehaviour:
         return RegistrationBehaviour.ALLOW
@@ -123,8 +123,8 @@ class TestLegacyRegistrationSpamChecker:
 class LegacyAllowAll(TestLegacyRegistrationSpamChecker):
     async def check_registration_for_spam(
         self,
-        email_threepid: Optional[dict],
-        username: Optional[str],
+        email_threepid: dict | None,
+        username: str | None,
         request_info: Collection[tuple[str, str]],
     ) -> RegistrationBehaviour:
         return RegistrationBehaviour.ALLOW
@@ -133,8 +133,8 @@ class LegacyAllowAll(TestLegacyRegistrationSpamChecker):
 class LegacyDenyAll(TestLegacyRegistrationSpamChecker):
     async def check_registration_for_spam(
         self,
-        email_threepid: Optional[dict],
-        username: Optional[str],
+        email_threepid: dict | None,
+        username: str | None,
         request_info: Collection[tuple[str, str]],
     ) -> RegistrationBehaviour:
         return RegistrationBehaviour.DENY
@@ -777,8 +777,8 @@ class RegistrationTestCase(unittest.HomeserverTestCase):
         self,
         requester: Requester,
         localpart: str,
-        displayname: Optional[str],
-        password_hash: Optional[str] = None,
+        displayname: str | None,
+        password_hash: str | None = None,
     ) -> tuple[str, str]:
         """Creates a new user if the user does not exist,
         else revokes all previous access tokens and generates a new one.
