@@ -20,7 +20,7 @@
 #
 
 
-from typing import Callable, Union
+from typing import Callable
 from unittest.mock import patch
 
 from zope.interface import implementer
@@ -104,7 +104,7 @@ class _DummyMessage:
 
 
 class SendEmailHandlerTestCaseIPv4(HomeserverTestCase):
-    ip_class: Union[type[IPv4Address], type[IPv6Address]] = IPv4Address
+    ip_class: type[IPv4Address] | type[IPv6Address] = IPv4Address
 
     def setUp(self) -> None:
         super().setUp()
