@@ -12,7 +12,7 @@
 # <https://www.gnu.org/licenses/agpl-3.0.html>.
 #
 import logging
-from typing import Any, Iterable, Literal, Optional
+from typing import Any, Iterable, Literal
 from unittest.mock import AsyncMock
 
 from parameterized import parameterized, parameterized_class
@@ -81,7 +81,7 @@ class SlidingSyncBase(unittest.HomeserverTestCase):
         return config
 
     def do_sync(
-        self, sync_body: JsonDict, *, since: Optional[str] = None, tok: str
+        self, sync_body: JsonDict, *, since: str | None = None, tok: str
     ) -> tuple[JsonDict, str]:
         """Do a sliding sync request with given body.
 
@@ -239,8 +239,8 @@ class SlidingSyncBase(unittest.HomeserverTestCase):
     def _create_remote_invite_room_for_user(
         self,
         invitee_user_id: str,
-        unsigned_invite_room_state: Optional[list[StrippedStateEvent]],
-        invite_room_id: Optional[str] = None,
+        unsigned_invite_room_state: list[StrippedStateEvent] | None,
+        invite_room_id: str | None = None,
     ) -> str:
         """
         Create a fake invite for a remote room and persist it.
